==> nextcloud-app-spreed-1:21.1.4-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/spreed/l10n/uz.js <==
OC.L10N.register(
    "spreed",
    {
    "Incoming call" : "Kiruvchi qo'ng'iroq",
    "Message deleted by author" : "Xabar muallif tomonidan o'chirildi",
    "Deleted user" : "Deleted user",
    "System" : "System",
    "File is too big" : "File is too big",
    "Invalid file provided" : "Invalid file provided",
    "Invalid image" : "Invalid image",
    "Unknown filetype" : "Unknown filetype",
    "Description" : "Tavsif",
    "Talk conversation for event" : "Tadbir uchun suhbat",
    "Accept" : "Qabul qiling",
    "Decline" : "Rad etish",
    "Reminder" : "Eslatma",
    "Notification" : "Bildirishnomalar",
    "error" : "Xatolik",
    "Everyone" : "Everyone",
    "Save changes" : "Save changes",
    "Saving …" : "Saqlanmoqda...",
    "Saved!" : "Saved!",
    "Name" : "Name",
    "Off" : "Oʻchirilgan",
    "Enable encryption" : "Enable encryption",
    "Pending" : "Pending",
    "Error" : "Xatolik",
    "Language" : "Language",
    "Status" : "Status",
    "OK" : "Yaxshi",
    "Checking …" : "Checking …",
    "Federated user" : "Korporativ foydalanuvchi",
    "Confirm" : "Confirm",
    "Reset" : "Qayta tiklash",
    "Back" : "Orqaga",
    "Cancel" : "Bekor qilish",
    "From" : "Dan",
    "To" : "Gacha",
    "Calendar" : "Calendar",
    "Attendees" : "Ishtirokchilar",
    "Save" : "Saqlash",
    "Done" : "Done",
    "Grid view" : "To‘r ko‘rinishi",
    "Copy link" : "Havolani nusxalash",
    "None" : "Yo'q",
    "Favorite" : "Favorite",
    "Date:" : "Sana:",
    "Hide details" : "Tafsilotlarni yashirish",
    "Show details" : "Tafsilotlarni ko'rsatish",
    "Disable" : "Oʻchirish",
    "Enable" : "Enable",
    "Choose" : "Choose",
    "Restricted" : "Cheklangan",
    "Meeting" : "Uchrashuv",
    "Personal" : "Personal",
    "No" : "No",
    "Yes" : "Yes",
    "Delete conversation" : "Delete conversation",
    "_%n hour_::_%n hours_" : ["%n soat"],
    "_%n day_::_%n days_" : ["%n kun"],
    "_%n week_::_%n weeks_" : ["%n hafta"],
    "Password protection" : "Parol himoyasi",
    "Edit" : "Tahrirlash",
    "Delete" : "O'chirish",
    "Notifications" : "Notifications",
    "Create a new conversation" : "Yangi suhbat yarating",
    "Log in" : "Kirish",
    "Remove from favorites" : "Sevimlilardan olib tashlang",
    "Add to favorites" : "Sevimlilarga qo'shing",
    "Home" : "Uy",
    "Users" : "Users",
    "Groups" : "Groups",
    "No search results" : "Qidiruv natijalari yo‘q",
    "Select a device" : "Qurilmani tanlang",
    "Upload" : "Yuklash",
    "Files" : "Fayllar",
    "Reply" : "Javob bering",
    "Translate" : "Tarjima",
    "Dismiss" : "Dismiss",
    "Contact" : "Aloqa",
    "Remove {fileName}" : " {fileName} ni o'chirish",
    "Today" : "Today",
    "Yesterday" : "Kecha",
    "Add emoji" : "Emoji qo'shing",
    "Upload from device" : "Qurilmadan yuklash",
    "Send" : "Send",
    "Settings" : "Sozlamalar",
    "Remove" : "O'chirish",
    "Searching …" : "Qidirilmoqda …",
    "Details" : "Details",
    "Search in {name}" : " {name}ni qidirish",
    "No results found" : "Hech qanday natija topilmadi",
    "Load more results" : "Ko'proq natijalarni yuklang",
    "Projects" : "Loyihalar",
    "Select conversation" : "Suhbatni tanlang",
    "Appearance" : "Tashqi ko'rinish",
    "Search" : "Qidirish",
    "More actions" : "Ko'proq harakatlar",
    "Password" : "Password",
    "Login" : "Login",
    "Client ID" : "Mijoz identifikatori",
    "Audio" : "Audio",
    "Other" : "Boshqa",
    "Show all files" : "Barcha fayllarni ko'rsatish",
    "Error while sharing file" : "Fayl almashishda xatolik yuz berdi",
    "Error while parsing a PROPFIND error" : "PROPFIND xatosini tahlil qilishda xatolik yuz berdi",
    "Please reload the page." : "Please reload the page.",
    "Do not disturb" : "Do not disturb",
    "Away" : "Away",
    "The password is wrong. Try again." : "Parol noto'g'ri. Qayta urinib ko'ring.",
    "Tasks" : "Tasks",
    "Notes" : "Notes",
    "Reports" : "Hisobotlar",
    "Close" : "Yopish"
},
"nplurals=1; plural=0;");

==> nextcloud-app-spreed-1:21.1.5-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/spreed/l10n/uz.js <==
OC.L10N.register(
    "spreed",
    {
    "Incoming call" : "Kiruvchi qo'ng'iroq",
    "Message deleted by author" : "Xabar muallif tomonidan o'chirildi",
    "Deleted user" : "Deleted user",
    "System" : "System",
    "File is too big" : "File is too big",
    "Invalid file provided" : "Invalid file provided",
    "Invalid image" : "Invalid image",
    "Unknown filetype" : "Unknown filetype",
    "Description" : "Tavsif",
    "Talk conversation for event" : "Tadbir uchun suhbat",
    "Accept" : "Qabul qiling",
    "Decline" : "Rad etish",
    "Reminder" : "Eslatma",
    "Notification" : "Bildirishnomalar",
    "error" : "Xatolik",
    "Everyone" : "Everyone",
    "Save changes" : "Save changes",
    "Saving …" : "Saqlanmoqda...",
    "Saved!" : "Saved!",
    "Name" : "Name",
    "Off" : "Oʻchirilgan",
    "Enable encryption" : "Enable encryption",
    "Pending" : "Pending",
    "Error" : "Xatolik",
    "Never" : "Hech qachon",
    "Language" : "Language",
    "Status" : "Status",
    "Yes" : "Yes",
    "No" : "No",
    "OK" : "Yaxshi",
    "Checking …" : "Checking …",
    "Federated user" : "Korporativ foydalanuvchi",
    "Confirm" : "Confirm",
    "Reset" : "Qayta tiklash",
    "Back" : "Orqaga",
    "Cancel" : "Bekor qilish",
    "From" : "Dan",
    "To" : "Gacha",
    "Calendar" : "Calendar",
    "Attendees" : "Ishtirokchilar",
    "Save" : "Saqlash",
    "No results" : "Natija yo'q",
    "Done" : "Done",
    "Grid view" : "To‘r ko‘rinishi",
    "Copy link" : "Havolani nusxalash",
    "None" : "Yo'q",
    "Favorite" : "Favorite",
    "Date:" : "Sana:",
    "Hide details" : "Tafsilotlarni yashirish",
    "Show details" : "Tafsilotlarni ko'rsatish",
    "Disable" : "Oʻchirish",
    "Enable" : "Enable",
    "Choose" : "Choose",
    "Restricted" : "Cheklangan",
    "Meeting" : "Uchrashuv",
    "Personal" : "Personal",
    "Delete conversation" : "Delete conversation",
    "_%n hour_::_%n hours_" : ["%n soat"],
    "_%n day_::_%n days_" : ["%n kun"],
    "_%n week_::_%n weeks_" : ["%n hafta"],
    "Password protection" : "Parol himoyasi",
    "Edit" : "Tahrirlash",
    "Delete" : "O'chirish",
    "Notifications" : "Notifications",
    "Create a new conversation" : "Yangi suhbat yarating",
    "Log in" : "Kirish",
    "Remove from favorites" : "Sevimlilardan olib tashlang",
    "Add to favorites" : "Sevimlilarga qo'shing",
    "Home" : "Uy",
    "Users" : "Users",
    "Groups" : "Groups",
    "Teams" : "Jamoalar",
    "No search results" : "Qidiruv natijalari yo‘q",
    "Select a device" : "Qurilmani tanlang",
    "Upload" : "Yuklash",
    "Files" : "Fayllar",
    "Reply" : "Javob bering",
    "Translate" : "Tarjima",
    "Dismiss" : "Dismiss",
    "Contact" : "Aloqa",
    "Remove {fileName}" : " {fileName} ni o'chirish",
    "Add emoji" : "Emoji qo'shing",
    "Upload from device" : "Qurilmadan yuklash",
    "Send" : "Send",
    "Settings" : "Sozlamalar",
    "Remove participant" : "Ishtirokchini olib tashlash",
    "Remove" : "O'chirish",
    "Searching …" : "Qidirilmoqda …",
    "Participants" : "Ishtirokchilar",
    "Details" : "Details",
    "Search in {name}" : " {name}ni qidirish",
    "No results found" : "Hech qanday natija topilmadi",
    "Load more results" : "Ko'proq natijalarni yuklang",
    "Projects" : "Loyihalar",
    "Select conversation" : "Suhbatni tanlang",
    "Appearance" : "Tashqi ko'rinish",
    "Keyboard shortcuts" : "Klaviatura yorliqlari",
    "Search" : "Qidirish",
    "More actions" : "Ko'proq harakatlar",
    "Submit" : "Submit",
    "Password" : "Password",
    "Login" : "Login",
    "Client ID" : "Mijoz identifikatori",
    "Audio" : "Audio",
    "Other" : "Boshqa",
    "Show all files" : "Barcha fayllarni ko'rsatish",
    "Default" : "Standart",
    "Error while sharing file" : "Fayl almashishda xatolik yuz berdi",
    "Error while parsing a PROPFIND error" : "PROPFIND xatosini tahlil qilishda xatolik yuz berdi",
    "Please reload the page." : "Please reload the page.",
    "Do not disturb" : "Do not disturb",
    "Away" : "Away",
    "The password is wrong. Try again." : "Parol noto'g'ri. Qayta urinib ko'ring.",
    "Tasks" : "Tasks",
    "Notes" : "Notes",
    "Reports" : "Hisobotlar",
    "Today" : "Today",
    "Yesterday" : "Kecha",
    "Close" : "Yopish"
},
"nplurals=1; plural=0;");
